@@ -19,10 +19,13 @@ class SignalRCoreConnection(ConnectionBase[HubMessage, HubInvocableMessage]):
         hub_name: str,
         protocol: Optional[Union[JsonProtocol, MessagePackProtocol]] = None,
         extra_params: Optional[Dict[str, str]] = None,
-        extra_headers: Optional[Dict[str, str]] = None,
+        http_client_options: Optional[Dict[str, Any]] = None,
+        ws_client_options: Optional[Dict[str, Any]] = None,
         logger: Optional[logging.Logger] = None,
     ):
-        super().__init__(base_url, extra_params, extra_headers, logger)
+        super().__init__(
+            base_url, extra_params, http_client_options, ws_client_options, logger
+        )
         self._url = self._base_url / hub_name
         self.protocol = protocol or JsonProtocol()
         self.handshake_protocol = JsonProtocol()
@@ -42,7 +45,7 @@ class SignalRCoreConnection(ConnectionBase[HubMessage, HubInvocableMessage]):
         async with self._session.post(
             self._url / command,
             params=params or self._common_params(),
-            headers=self._extra_headers,
+            **self._http_client_options,
         ) as resp:
             resp.raise_for_status()
             return await resp.json()
